import { it, expect, describe, beforeEach, afterEach, vi } from 'vitest'
import { createPinia, setActivePinia } from 'pinia'
import { useCommunityStore } from '@/stores/community'
import { Quasar } from 'quasar'
import App from '@/App.vue'
import { i18n } from '@/plugins/i18n'
import { settingsStorage as storage } from '@/services/storageService'
import { createRouter, createWebHistory } from 'vue-router'
import { mount } from '@vue/test-utils'
import type { TestWrapper } from '../types'


const router = createRouter({
  history: createWebHistory(),
  routes: [
    {
      path: '/',
      component: {
        template: '<div></div>'
      },
      meta: { layout: 'Custom' },
    },
  ],
})

describe('Homepage', function () {
  setActivePinia(createPinia())
  const communityStore = useCommunityStore()
  let wrapper: TestWrapper<{layout: string}>

  const mountApp = (shallow = false, options = {}) =>
      wrapper = mount(App, {
        global: {
          plugins: [i18n, Quasar, router],
          stubs: {
            Notifications: { template: '<div id="notifications-menu"/>',},
            usfRenderer: true,
            Hopla: true,
          },
          ...options,
        },
        shallow
      })
  beforeEach(() => {
    communityStore.projectList = {
      pageContent: []
    }
    storage.clear()
  })

  afterEach(() => {
    vi.restoreAllMocks()
    wrapper.unmount()
  })
  it('should have a default layout component', () => {
    mountApp(true);
    expect(wrapper.vm).toHaveProperty('layout');
    expect(wrapper.vm.layout).toEqual('ULayoutDefault')
  })
})
