// TODO check usage of commented and optional keys
import type { MediaFile } from '#/file'
import { RendererName } from '#/file'

export interface SetItem {
  canEdit?: boolean; // rights for project manager
  description: string;
  id: string;
  isPublic?: boolean;
  thumbnails: ThumbnailSource;
  title: string;
  updatedAt: string;
}
export interface SearchItemSet {
  id: string;
  title: string;
}

/** type depends on Item multiple and repeatable properties */
export type ItemValue = string | string[] | Array<string[]>

export interface Metadata {
  id: string; // template field id
  name: string; // template field name
  value: ItemValue; // field value, values or list of values
  multiple?: boolean; // template field allow multiple values
  isOption?: boolean; // its value is an option of template field, see MetaSaveMixin
  repeatable?: boolean; // values will be dispatch into duplicated fields
}
export interface SearchItemMetadata {
  creator: string[];
  publisher: string;
  publicationYear: number;
  resourceType: string;
  resourceTypeGeneral: string;
}


export interface FileViewer {
  component: RendererName; // name of component used to read the file
  fileId: string; // id of the MediaFile to be read
  isDownloadable: boolean; // control download button visibility
}

export interface ThumbnailSource {
  s?: string; // url to object's 48×48 thumbnail
  m?: string; // url to object's 64×64 thumbnail
  l?: string; // url to object's 128×128 thumbnail
  embed?: string; // url to object's 512×512 thumbnail
}

export interface ItemCreator {
  id: string;
  name: string;
  username: string;
  email: string;
}
export type SearchItemCreator = Omit<ItemCreator, 'username' | 'email'>

export interface ItemDetail {
  description: string;
  isPublic: boolean;
}

export interface NewItem extends ItemDetail {
  metadata: Metadata[];
  setId?: string; // - parent set id
  title: string; // - 255 chars max
}
export interface PountItem extends NewItem{
  canEdit?: boolean; // true if user is project manager or creator of this item
  canBeShared?: boolean; // true if itself, its parents set and project are public
  creator: ItemCreator;
  id: string;
  mediaFiles: MediaFile[];
  set?: ItemSet; // - parent set details
  thumbnails: ThumbnailSource; // - urls of thumbnails
  viewer: FileViewer | null // viewer parameters
}
export interface SearchItem {
  id: string;
  title: string;
  description: string;
  metadata: SearchItemMetadata;
  creator: SearchItemCreator;
  isPublic: boolean;
  thumbnail?: string
  project: SearchItemCreator;
  set: SearchItemSet;
  score: number;
  highlight: SearchItemHighlight
}

export interface ItemStoreState {
  current: NewItem | PountItem;
  setItems: SetItem[];
  setItemsCount: number;
  pageCount: number;
}

export type DuplicationTarget = {setId: string, metadata: Metadata[]}
