export interface Hierarchy {
  name: string;
  id: string;
}

export interface Node {
  id: string;
  name: string;
  ancestors?: string[];
  children?: string[];
  level: number;
}

export type LanguageDefinition = {
  label: string;
  code: string;
}

export type Translation = Record<string, string>

export type ReferentialLanguages = {
  available: string[];
  default: string | null;
  translations: Record<string, Translation>;
}

export type ReferentialDefinition = {
  levels: Hierarchy[];
  roots: string[];
  nodes: Record<string, Node>
}

export interface NewReferential {
  name: string;
  description: string;
  projectId?: string;
  scope: number;
  languages: ReferentialLanguages;
  definition: ReferentialDefinition;
}

export interface Referential extends NewReferential {
  id: string;
  creator: {id: string; name: string};
  project: {id: string; name: string} | null;
  currentVersion: boolean;
  version: string | null;
  versionLabel: string | null;
  rootVersion: string | null;
  source: string;
  lists: object[];
  createdAt: string;
  updatedAt: string;
}


export interface ReferentialState {
  langIso: LanguageDefinition[];
  codeToLang: Record<string, LanguageDefinition>;
  referential: NewReferential | Referential;
  projectReferentials: ProjectReferential[];
  projectReferentialsCount: number;
  pageCount: number;
}

export interface ProjectReferential {
  id: string;
  name: string;
  description: string;
  scope: 1 | 2 | 4;
  isManager: boolean;
  isExternal: boolean;
  createdAt: string;
  updatedAt: string;
  project?: {
    id: string;
    name: string;
  }
}

export interface ReferentialFilters {
  search?: string;
  project?: string;
}
